@@ -61,16 +61,6 @@ class ContinuousDomain(Domain):
         seed = kwargs.pop('seed', None)
 
         self.callback = callback if callback is not None else lambda x: x
-        self.seed = seed
-
-
-        if seed is not None:
-            if isinstance(seed, int):
-                seed = np.random.RandomState(seed)
-            kwargs['random_state'] = seed
-        else:
-            seed = np.random.RandomState(np.random.randint(int(2**32 - 1), dtype=np.uint32))
-            kwargs['random_state'] = seed
 
         self.domain_args = args
         self.domain_kwargs = kwargs
@@ -112,23 +102,13 @@ class ContinuousDomain(Domain):
 
     @classmethod
     def from_json(cls, obj):
-        if 'random_state' in obj['domain_kwargs']:
-            rng = obj['domain_kwargs']['random_state']
-            random_state = np.random.RandomState()
-            random_state.set_state((rng[0], np.array(rng[1], dtype=np.uint32),
-                                    rng[2], rng[3], rng[4]))
-            del obj['domain_kwargs']['random_state']
-        else:
-            random_state = obj['domain_kwargs']['random_state']
-            del obj['domain_kwargs']['random_state']
-
         try:
             callback = dill.loads(obj['callback'])
         except KeyError:
             callback = None
 
         domain = cls(obj['name'], obj['domain'], *obj['domain_args'],
-                     callback=callback, seed=random_state,
+                     callback=callback,
                      **obj['domain_kwargs'])
         
         domain.id = obj['id']
@@ -139,7 +119,10 @@ class ContinuousDomain(Domain):
     def generate(self):
         """Generate a hyperparameter value from this domain."""
         return self.callback(
-            self.domain.rvs(*self.domain_args, **self.domain_kwargs))
+            self.domain.rvs(
+                *self.domain_args,
+                random_state=self._rng.rng,
+                **self.domain_kwargs))
 
     def map_to_domain(self, value, bound=False):
         return value
@@ -163,14 +146,7 @@ class ContinuousDomain(Domain):
         jsonified.update({
             'domain': self.domain.name,
             'domain_args': self.domain_args,
-            'domain_kwargs': {}
+            'domain_kwargs': {k: v for k, v in self.domain_kwargs.items()}
         })
 
-        for key, val in self.domain_kwargs.items():
-            if key == 'random_state' and isinstance(val, np.random.RandomState):
-                rs = val.get_state()
-                jsonified['domain_kwargs'].update({'random_state': rs})
-            else:
-                jsonified['domain_kwargs'][key] = val
-
         return jsonified
