@@ -74,6 +74,9 @@ class DependentDomain(Domain):
         """Generate a hyperparameter value from this domain."""
         return self.callback(self.domain.current)
 
+    def map_to_domain(self, index, bound=True):
+        pass
+
     def to_index(self, value):
         """Convert a value to its index in the domain."""
         try:
