@@ -3,6 +3,7 @@ from .pso import PSO as pso
 from .random_search import RandomSearch as random
 from .smac import SMAC as smac
 from .tpe import TPE as tpe
+from .ncqs import NCQS as ncqs
+from .hom import HOM as hom
 
-
-__all__ = ['bayes', 'pso', 'random', 'smac', 'tpe']
+__all__ = ['bayes', 'pso', 'random', 'smac', 'tpe', 'ncqs', 'hom']
