@@ -13,11 +13,13 @@ PopulationBilevelMethod
 """
 import copy
 import inspect
-from queue import LifoQueue
+import queue
 import uuid
 
 import numpy as np
 
+from pyrameter.reproducibility import RNG
+
 
 class Method():
     """Abstract class on which to develop optimization methods.
@@ -42,7 +44,8 @@ class Method():
         self.id = str(uuid.uuid4())
         self.warm_up = warm_up
         self.n_generated = 0
-        self.parameter_queue = LifoQueue()
+        self.parameter_queue = queue.Queue()
+        self.random_state = None
 
     def __call__(self, space):
         """Handler for generating hyperparameters.
@@ -106,10 +109,15 @@ class Method():
             #     )
             
             for i in range(parameters.shape[0]):
-                self.parameter_queue.put_nowait(parameters[i])
+                self.parameter_queue.put(parameters[i])
 
+        parameters = None
         if not self.parameter_queue.empty():
-            parameters = self.normalize(space, self.parameter_queue.get_nowait())
+            try:
+                parameters = self.parameter_queue.get(timeout=10)
+                parameters = self.normalize(space, parameters)
+            except queue.Empty:
+                parameters = None
 
         return parameters
 
@@ -177,6 +185,9 @@ class Method():
         """
         return [d.bound_index(h)
                 for (d, h) in zip(space.domains, hyperparameters)]
+    
+    def set_rng(self, rng):
+        self.random_state = rng
 
     def to_json(self):
         """Convert method state to a JSON-compatible dictionary.
@@ -357,6 +368,10 @@ class BilevelMethod(Method):
         
         self.inner_method = inner_method
 
+    def set_rng(self, rng):
+        self.inner_method.set_rng(rng)
+        super().set_rng(rng)
+
 
 class BilevelPopulationMethod(PopulationMethod):
     """Abstract class on which to develop bilevel population-based optimization methods.
@@ -411,4 +426,8 @@ class BilevelPopulationMethod(PopulationMethod):
                 f'Provided inner method {inner_method} is not a subclass ' +
                  'of pyrameter.methods.Method nor a valid callable.')
         
-        self.inner_method = inner_method
\ No newline at end of file
+        self.inner_method = inner_method
+
+    def set_rng(self, rng):
+        self.inner_method.set_rng(rng)
+        super().set_rng(rng)
